@@ -20,6 +20,7 @@ from .util import (
     make_dataclass_picklable,
     partial_call,
     validate_literal_field,
+    ConfigError,
     LiteralError,
     MissingValue,
 )
@@ -39,6 +40,7 @@ __all__ = [
     "make_dataclass_picklable",
     "assert_check_literals",
     "validate_literal_field",
+    "ConfigError",
     "LiteralError",
     "MissingValue",
 ]
